#' @importFrom utils globalVariables
utils::globalVariables("package_rss")
